starcluster.commands.start.CmdStart

Package starcluster :: Package commands :: Module start :: Class CmdStart |
[hide private]
[frames] | no frames]

# Class CmdStart

source code

    start [options] <cluster_tag>

    Start a new cluster

    Example:

        $ starcluster start mynewcluster

    This will launch a cluster named "mynewcluster" using the settings from
    the default cluster template defined in the configuration file. The
    default cluster template is specified by the 'default_template' option in
    the [global] section of the config. To use another template besides the
    default use the --cluster-template option:

        $ starcluster start --cluster-template largecluster mynewcluster

    This will do the same thing only using the settings from the "largecluster"
    cluster template defined in the config.

Instance Methods | [hide private]
addopts(self, parser) | source code
cancel_command(self, signum, frame) Exits program with return value of 1 | source code
execute(self, args) | source code
Inherited from `completers.ClusterCompleter` (private): `_completer` Inherited from `completers.Completer` (private): `_prep_for_completion` Inherited from `base.CmdBase`: `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| names = ``[``'``start``'``]``
| tag = `None` hash(x)
Inherited from `completers.Completer` (private): `_cfg` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `completers.Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`

Method Details | [hide private]

### addopts(self, parser) | source code
Overrides: base.CmdBase.addopts

### cancel_command(self, signum, frame) | source code
Exits program with return value of 1 Overrides: base.CmdBase.cancel_command (inherited documentation)